/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.common.ui.javafx.control.treetableview;

import static java.util.Collections.emptyList;
import static java.util.stream.Collectors.toList;

import java.util.Collection;
import java.util.function.Supplier;
import java.util.stream.Stream;

/**
 * Content provider whose element list is dynamically retrieved from a supplier.
 * 
 * @author diewald
 */
public class DynamicStreamContentProvider<T, S extends Supplier<Stream<T>>>
		extends DynamicTreeContentProviderBase<T> {

	/** {@inheritDoc} */
	@Override
	protected Collection<? extends T> getChildren(T parent) {
		if(parent instanceof Supplier) {
			@SuppressWarnings("unchecked") Supplier<Stream<T>> supp = ((S)parent);
			return supp.get().collect(toList());
		}
		return emptyList();
	}
}
